#
# spec file for package python-pydicom
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pydicom
Version:        3.0.1
Release:        1.1
Summary:        Pure python package for DICOM medical file reading and writing
License:        MIT
URL:            https://github.com/darcymason/pydicom
Source:         https://github.com/pydicom/pydicom/archive/refs/tags/v%{version}.tar.gz#/pydicom-%{version}-gh.tar.gz

BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module flit-core >= 3.2}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module pydicom-data}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
# /SECTION
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
pydicom is a pure python package for parsing DICOM files
into natural pythonic structures for further manipulation.
Modified datasets can be written again to DICOM format files.

DICOM is a standard (http://medical.nema.org) for communicating
medical images and related information such as reports
and radiotherapy objects.

%prep
%autosetup -p1 -n pydicom-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pydicom
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8

%{python_expand # see https://github.com/pydicom/pydicom/issues/1697
mkdir build/locallib
cp -r %{$python_sitelib}/data_store %{$python_sitelib}/pydicom_data*.dist-info build/locallib/
}
export PYTHONPATH=$PWD/build/locallib
# these assume that a cache is updatable from online downloads
skips="test_fetch_data_files"
skips="$skips or test_get_testdata_file_external_hash_mismatch"
skips="$skips or test_get_testdata_files_local_external_and_cache"
skips="$skips or test_get_testdata_files_hash_match"
skips="$skips or test_get_testdata_files_hash_mismatch"
skips="$skips or test_get_testdata_files_external_ignore_hash"

skips="$skips or test_decoder_base"
skips="$skips or test_decoder_native"
skips="$skips or test_utils"
skips="$skips or test_dataset"

if [ "$RPM_ARCH" = "ppc64le" -o "$RPM_ARCH" = "aarch64" -o "$RPM_ARCH" = "riscv64" ]; then
  skips="$skips or TestPillowHandler_JPEG2K"
fi
if [ $(getconf LONG_BIT) -eq 32 ]; then
  # Failures on i586
  skips="$skips or test_write_file_id or test_file_id or test_encapsulate_bot_large_raises or (TestPillowHandler_JPEG2K and test_array)"
fi

%pytest -rsfR $ignores -k "not ($skips)"

%post
%python_install_alternative pydicom

%postun
%python_uninstall_alternative pydicom

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/pydicom
%{python_sitelib}/pydicom
%{python_sitelib}/pydicom-%{version}.dist-info

%changelog
* Thu Apr 17 2025 Steve Kowalik <steven.kowalik@suse.com>
- Drop BuildRequires on gdcm to skip tests.
* Sun Mar 23 2025 Axel Braun <axel.braun@gmx.de>
- version 3.0.1
  * patch removed: pydicom-pr1908-fixpillow.patch
  * patch removed: pydicom-pr2076-np2.patch
  * some tests disabled
  * changes in 3.0.1:
  * Changed logging of missing plugin imports to use :attr:`logging.DEBUG` (:issue:`2128`).
  * Include all :mod:`~pydicom.examples` module datasets with the package (:issue:`2128`, :issue:`2131`)
  * Fixed an invalid VR value in the private data dictionary (:issue:`2132`).
  * Fixed checking for *Bits Stored* when converting *Float Pixel Data* and *Double Float
    Pixel Data* using the :mod:`~pydicom.pixels` backend (:issue:`2135`).
  * Fixed decoding of pixel data for images with *Bits Allocated* of 1 when frame boundaries are not aligned with byte boundaries (:issue:`2134`).
  * changes in 3.0: seer release_notes/v3.0.0.rst
* Wed Sep  4 2024 Ben Greiner <code@bnavigator.de>
- Add pydicom-pr2076-np2.patch backport of gh#pydicom/pydicom#2076
* Mon Feb 19 2024 Andreas Schwab <schwab@suse.de>
- Skip TestPillowHandler_JPEG2K also on riscv64
* Thu Jan 25 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.4.4
  [#]# Changes
  * Removed support for Python 3.6 (EOL since December 2021)
  [#]# Enhancements
  * Added attribute alphabetic (#1634)
  * Added attribute json_key (#1648)
  * Added value validation for numerical VRs, add type validation
    for all validated VRs (#1414)
  * CLI commands now accept pydicom charset test files and CLI help
    shows Python Version (#1674)
  * Added support for Python 3.11 (#1658)
  * Added ISfloat to allow non-strict reading of existing files
    with float IS values (#1661)
  * Improved speed of creating and accessing highly nested
    structures (#1728, #1734)
  * Switched to a pyproject.toml build process (#1792)
  * Updated DICOM and UID dicts to DICOM 2023b (#1803)
  [#]# Fixes
  * Fixed length validation of DS values with maximum length
    without a leading zero (#1632)
  * Increased download speed with progress bar for test data
    (#1611)
  * Fixed crash due to invalid private creator (#1638)
  * Fixed extremely long BytesLengthException error messages
    (#1683)
  * In codify, ensure unique variable names for DICOM keywords
    repeated in sequences, and handle unicode characters correctly
    (#1670)
  * Fixed handling of some invalid values in to_json_dict() if
    suppress_invalid_tags is set to True (#1693)
  * Fixed reading of data with 8 bits allocated, encoded in Big
    Endian transfer syntax using VR OW (#1680)
  * Fixed crash if reading regular dataset that has the SOP Class
    of a DICOMDIR (#1702)
  * Fixed wrong waveform data calculation when as_raw=False and
    baseline!=0 (#1667)
  * Fixed reading LUTData to expected size (#1747)
  * Fixed handling of AT VRs when codifying data elements (#1738)
  [#]# Pydicom Internals
  * In test suites, renamed ‘setup’ and ‘teardown’ methods,
    deprecated starting in pytest 7.2
  * Use own fork of CharPyLS to handle builds with Python 3.11
    (#1788)
- Go back do %%{?sle15_python_module_pythons}. python- prefixed
  packages for Python 3.6 should be handled by separate maintenance
  request to python3-pydicom on SLE side
- Add pydicom-pr1908-fixpillow.patch
  * gh#pydicom/pydicom#1908 fixes gh#pydicom/pydicom#1907
* Tue Jan 16 2024 Axel Braun <axel.braun@gmx.de>
- switch to wheel and enable %%{?sle15allpythons}
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.3.1:
  * Small fix to make 2.3.X compatible with Python 3.11.
* Mon Oct 10 2022 John Vandenberg <jayvdb@gmail.com>
- Add BD pydicom-data test data, and unskip many tests that now pass
* Sat Sep 24 2022 John Vandenberg <jayvdb@gmail.com>
- Skip a lot of tests, mostly due to missing test data, but there
  are over 1900 still passing.
- Update to v2.3.0
  * See https://github.com/pydicom/pydicom/tree/master/doc/release_notes
* Fri Dec 10 2021 pgajdos@suse.com
- do not require pytest-runner for build
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.2:
  * no upstream changelog
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.0:
  * no upstream changelog
* Fri Mar  8 2019 John Vandenberg <jayvdb@gmail.com>
- Reinstate test unit test_code_file which appears to be stable now
- Use PyPI sdist as source
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.2:
  * more python 3.7 fixes
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * No obvious upstream changelog
- Drop python37.patch should be fixed upstream
* Thu Aug 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Disable test_code_file as it randomly fails in OBS
* Wed Aug 29 2018 tchvatal@suse.com
- Update to 1.1.0:
  * License is distributed
  * Various speed improvements
- Add patch to work with python 3.7:
  * python37.patch
* Mon Sep 11 2017 jengelh@inai.de
- Make package description neutral and compact it.
* Mon Sep 11 2017 toddrme2178@gmail.com
- Implement single-spec version
* Thu Oct 13 2016 toddrme2178@gmail.com
- Update to version 0.9.9
  + Major changes / enhancements
  * All dicom dictionaries updated (standard dictionary, UID
    dictionary, and private dictionaries)
  * Dicom commands also added to dictionary
  * Ability to work with DICOMDIR:  read_dicomdir() function and
    DicomDir class. Example file show_dicomdir.py file added to
    examples subdirectory.
  * codify.py: Produce python/pydicom source code from a dicom
    file.
  * a number of python 3 compatibility enhancements
  * setup.py uses ez_setup only if setuptools not already
    installed
  * exceptions carry tag info with them, to aid in debugging
  + Contrib file changes
  * pydicom_series:  force parameter added (Nil Goyette)
  * dcm_qt_tree: switch to OrderedDict to preserve ordering of
    tags (Padraig Looney)
- Rename package to python-dicom to python-pydicom to conform to python
  package naming policies.
- spec file completely rewritten.
- Remove unneeded python-dicom-remove-obsolete-distribute-support.patch
* Tue Dec 17 2013 p.drouand@gmail.com
- Update to version 0.9.8
  + No changelog available
- Add python-dicom-remove-obsolete-distribute-support.patch; setup
  script try to import setuptools from distribute
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Aug 17 2012 scorot@free.fr
- fix build for SLE 11 x86_64
* Tue Aug  7 2012 toddrme2178@gmail.com
- Initial version
